/*
Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'docprops', 'nb', {
	bgColor: 'Bakgrunnsfarge',
	bgFixed: 'Lås bakgrunnsbilde når man scroller (fixed)',
	bgImage: 'URL for bakgrunnsbilde',
	charset: 'Tegnsett',
	charsetASCII: 'ASCII',
	charsetCE: 'Sentraleuropeisk',
	charsetCR: 'Kyrillisk',
	charsetCT: 'Tradisonell kinesisk (Big5)',
	charsetGR: 'Gresk',
	charsetJP: 'Japansk',
	charsetKR: 'Koreansk',
	charsetOther: 'Annet tegnsett',
	charsetTR: 'Tyrkisk',
	charsetUN: 'Unicode (UTF-8)',
	charsetWE: 'Vesteuropeisk',
	chooseColor: 'Velg',
	design: 'Design',
	docTitle: 'Sidetittel',
	docType: 'Header for dokumenttype',
	docTypeOther: 'Annen header for dokumenttype',
	label: 'Dokumentegenskaper',
	margin: 'Sidemargin',
	marginBottom: 'Bunn',
	marginLeft: 'Venstre',
	marginRight: 'Høyre',
	marginTop: 'Topp',
	meta: 'Metadata',
	metaAuthor: 'Forfatter',
	metaCopyright: 'Opphavsrett',
	metaDescription: 'Dokumentbeskrivelse',
	metaKeywords: 'Dokumentnøkkelord (kommaseparert)',
	other: '<annen>',
	previewHtml: '<p>Dette er en <strong>eksempeltekst</strong>. Du bruker <a href="javascript:void(0)">CKEditor</a>.</p>',
	title: 'Dokumentegenskaper',
	txtColor: 'Tekstfarge',
	xhtmlDec: 'Inkluder XHTML-deklarasjon'
} );
